
;;; howm site-lisp configuration

(add-to-list 'load-path "@SITELISP@")
(autoload 'howm-menu "howm" nil t)
